pub enum Error {
OpenRepo {
path: PathBuf,
source: Box<Error>,
},
References(Error),
ReferencesInit(Error),
Peel(String),
TagObject(String),
TagNotFound(String),
Object(String),
TreeTraversal(String),
TempDir(Error),
TagCreate(String),
}Expand description
Errors that can occur during git repository operations.
Variants
OpenRepo
Failed to open a git repository at the given path.
Fields
References(Error)
Failed to initialise the reference iterator.
ReferencesInit(Error)
Failed to create the reference iterator platform.
Peel(String)
Failed to peel a reference to its target object.
TagObject(String)
Failed to read a tag object from the repository.
TagNotFound(String)
The requested tag ref does not exist in the repository.
Object(String)
Failed to resolve or decode a git object.
TreeTraversal(String)
Failed to traverse the tree entries.
TempDir(Error)
Failed to create a temporary directory.
TagCreate(String)
Git tag creation or deletion command failed.